#include "StdAfx.h"
#include "ChessClock.h"

ChessClock::ChessClock(WORD k, int playT, int inc2)
{
  Init(playT, inc2);
  SetSwitchKey(k);
  running = false;
  bronstein = false;
  status = 1; //stopped
}

void ChessClock::SetSwitchKey(WORD k)
{
  switchKey = k;
}

bool ChessClock::IsSwitchKey(WORD k)
{
  return (switchKey == k);
}

void ChessClock::Init(int playT, int inc2, bool br)
{
  playTime = playT;
  time = playT*600;
  if (time == 0) time = 100;
  beginTime = time;
  inc = inc2;
  bronstein = br;
}

bool ChessClock::IsRunning()
{
  return running;
}

void ChessClock::Stop()
{
  running = false;
  beginTime = time;
  status = 3; //waiting
}

void ChessClock::Run()
{
  running = true;
  status = 2; //running
}

bool ChessClock::IsOver()
{
  return (time <= 0);
}

void ChessClock::Dec()
{
  time--;
  if (time <= 0)
	  status = 4; //flagged
}

void ChessClock::Inc()
{
  time += inc*10;
  if (bronstein && time > beginTime)
	  time = beginTime;
}

string ChessClock::GetTime()
{
  int h,m,s,ds;

  h = time/36000;
  m = (time-h*36000)/600;
  s = (time-(h*36000+m*600))/10;
  ds= time%10;
  if (h>0) {
    timeStr = i2str(h);
    timeStr += ":";
  } else timeStr = "";
  if ((m < 10) && (h > 0)) {
    timeStr += "0";
  }
  timeStr += i2str(m);
  timeStr += ":";
  if (s < 10) timeStr += "0";
  timeStr += i2str(s);
  if ((h == 0) && (m == 0) && (s < 10)) {
    timeStr += ".";
    timeStr += i2str(ds);
  }
  return timeStr;
}

void ChessClock::Reset()
{
  time = playTime*600;
  beginTime = time;
  status = 1; //stopped
}

void ChessClock::Moretime(int i)
{
  time += i*10;
  beginTime = time;
}

int ChessClock::GetStatus()
{
  return status;
}

void ChessClock::SetStatus(int s)
{
  status = s;
}

void ChessClock::Pause()
{
  if (status == 2)  { //running
	Stop();
	status = 0; //ready
  }
  if (status == 3)  { //waiting
	status = 1; //stopped
  }
}

void ChessClock::Unpause()
{
  if (status == 1) { //stopped
	status = 3; //waiting
  }
  if (status == 0) { //ready
	status = 2; //running
	Run();
  }
}
